# Page 2


## Sidenotes

Some text to test out one sidenote[^myref] and another sidenote[^3]

[^myref]: This is a sidenote.

[^3]: This is *another* **sidenote**.

## Marginnotes

Some text to test out one marginnote[^somemargin] and another marginnote[^6]

[^somemargin]: {-} This is a marginnote.
[^6]: {-} This is *another* **marginnote**.

This is the end of Page 2.
